@@ -113,6 +113,9 @@ SetCallback(Handle<ObjectTemplate> obj, const char *name,
 
 class SubTranBlock
 {
+private:
+	ResourceOwner	m_resowner;
+	MemoryContext m_mcontext;
 public:
 	SubTranBlock();
 	void enter();
@@ -123,6 +126,7 @@ Persistent<ObjectTemplate> PlanTemplate;
 Persistent<ObjectTemplate> CursorTemplate;
 Persistent<ObjectTemplate> WindowObjectTemplate;
 
+
 static Handle<v8::Value>
 SPIResultToValue(int status)
 {
@@ -165,8 +169,11 @@ SubTranBlock::enter()
 	if (!IsTransactionOrTransactionBlock())
 		throw js_error("out of transaction");
 
-	BeginInternalSubTransaction(NULL);
+	m_resowner = CurrentResourceOwner;
+	m_mcontext = CurrentMemoryContext;
 
+	BeginInternalSubTransaction(NULL);
+	MemoryContextSwitchTo(m_mcontext);
 }
 
 void
@@ -177,7 +184,8 @@ SubTranBlock::exit(bool success)
 	else
 		RollbackAndReleaseCurrentSubTransaction();
 
-
+	MemoryContextSwitchTo(m_mcontext);
+	CurrentResourceOwner = m_resowner;
 }
 
 JSONObject::JSONObject()
